@@ -71,12 +71,14 @@ def deployModel(api_token, account_name, account_id, model_name, version_name, p
     # TODO: consider doing this AFTER we successfully upload the model
     # TODO: look up model type 
     # TODO: return namespace name when we write it successfully
-
+    if memoryLimit < 0.0:
+        print(f"Error. You must provide a memory limit that is greater than 0. You provided {memoryLimit}")
+        return(False)
     if(check_string(model_name)==False):
-        print("The model name you provided, "+model_name+", does not match our naming convention. Please check our documentation for instructions: https://docs.pyqai.com/pyq/fundamentals/naming-conventions")
+        print("Error. The model name you provided, "+model_name+", does not match our naming convention. Please check our documentation for instructions: https://docs.pyqai.com/pyq/fundamentals/naming-conventions")
         return(False)
     if(check_string(version_name)==False):
-        print("The version name you provided, "+version_name+", does not match our naming convention. Please check our documentation for instructions: https://docs.pyqai.com/pyq/fundamentals/naming-conventions")
+        print("Error. The version name you provided, "+version_name+", does not match our naming convention. Please check our documentation for instructions: https://docs.pyqai.com/pyq/fundamentals/naming-conventions")
         return(False)
 
     requestBodyGetToken = {"account_id": account_id}
@@ -202,23 +204,25 @@ def deployModel(api_token, account_name, account_id, model_name, version_name, p
     calculated_mem_util = 0
 
     # run the container so that we can get some stats on it.
-    docker_run = docker_client.containers.run(push_tag, detach = True, ports = {8080:8080})
-    print(docker_run)
-    sleep(3)
-    stats = docker_run.stats(decode=None, stream = False)
-    if verbose_logging : print("INFO: docker container stats: " + str(stats))
-    #THIS IS IN BYTES, need to convert to MiB or GiB before passing into the yaml file
-    mem_usage = stats['memory_stats']['usage']
-    # TODO: don't use the magic numbers here, not optimal.
-    membibytes_mem_usage = mem_usage / 1048576
-    gibibytes_mem_usage = membibytes_mem_usage / 1024
-    if verbose_logging : print(f"INFO: docker container memory usage in gibibytes: {gibibytes_mem_usage}")
-    # Still unaware what unit this is in.
-    cpu_usage = stats['cpu_stats']['system_cpu_usage']
-    if verbose_logging : print(f"INFO: docker container cpu_usage in unknown units: {cpu_usage}")
-    docker_run.stop()
+    if(memoryLimit == -999.9): # ie the user does not provide a memory limit
+        if verbose_logging : print("INFO: Running Docker image to identify memory limit")
+        docker_run = docker_client.containers.run(push_tag, detach = True, ports = {8080:8080})
+        print(docker_run)
+        sleep(3)
+        stats = docker_run.stats(decode=None, stream = False)
+        if verbose_logging : print("INFO: docker container stats: " + str(stats))
+        #THIS IS IN BYTES, need to convert to MiB or GiB before passing into the yaml file
+        mem_usage = stats['memory_stats']['usage']
+        # TODO: don't use the magic numbers here, not optimal.
+        membibytes_mem_usage = mem_usage / 1048576
+        gibibytes_mem_usage = membibytes_mem_usage / 1024
+        if verbose_logging : print(f"INFO: docker container memory usage in gibibytes: {gibibytes_mem_usage}")
+        # Still unaware what unit this is in.
+        cpu_usage = stats['cpu_stats']['system_cpu_usage']
+        if verbose_logging : print(f"INFO: docker container cpu_usage in unknown units: {cpu_usage}")
+        docker_run.stop()
 
-    calculated_mem_util = gibibytes_mem_usage + gibibytes_memory_size
+        calculated_mem_util = gibibytes_mem_usage + gibibytes_memory_size
 
     if memoryLimit == None or memoryLimit <= 0: 
         if(calculated_mem_util < 3.0):
